This crate contains kube-rs compatible bindings for Kubernetes custom resources for the operator.authorino.kuadrant.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
operator.authorino.kuadrant.io/v1beta1
Authorino